import { socialUserInfoGuard } from '@logto/connector-kit';
import { z } from 'zod';

// Since the SAML SSO user info will extend the basic social user info (will contain extra info like `organization`, `role` etc.), but for now we haven't decide what should be included in extended user info, so we just use the basic social user info guard here to keep SSOT.
const samlAttributeMappingGuard = socialUserInfoGuard;

// eslint-disable-next-line no-restricted-syntax
export const defaultAttributeMapping = Object.fromEntries(
  Object.keys(samlAttributeMappingGuard.shape).map((key) => [key, key])
) as AttributeMap;

const customizableAttributeMappingGuard = samlAttributeMappingGuard.partial();
export type CustomizableAttributeMap = z.infer<typeof customizableAttributeMappingGuard>;
export type AttributeMap = Required<CustomizableAttributeMap>;

/**
 * This is the metadata of SAML service provider, automatically generated by `tenantId` and `ssoConnectorId`.
 * See details in {@link @logto/core/src/sso/SamlConnector/index.ts}.
 */
const samlServiceProviderMetadataGuard = z.object({
  entityId: z.string().min(1),
  assertionConsumerServiceUrl: z.string().min(1),
});

export type SamlServiceProviderMetadata = z.infer<typeof samlServiceProviderMetadataGuard>;

/**
 * We only concern about the `entityId`, `signInEndpoint` and `x509Certificate` for now.
 */
export const samlIdentityProviderMetadataGuard = z.object({
  entityId: z.string(),
  signInEndpoint: z.string(),
  x509Certificate: z.string(),
});

export type SamlIdentityProviderMetadata = z.infer<typeof samlIdentityProviderMetadataGuard>;

export const samlConnectorConfigGuard = samlIdentityProviderMetadataGuard
  .extend({
    attributeMapping: customizableAttributeMappingGuard,
    metadata: z.string(),
    metadataUrl: z.string(),
  })
  .partial();

export type SamlConnectorConfig = z.infer<typeof samlConnectorConfigGuard>;

const samlMetadataGuard = z.object({
  serviceProvider: samlServiceProviderMetadataGuard,
  identityProvider: samlIdentityProviderMetadataGuard,
});

export type SamlMetadata = z.infer<typeof samlMetadataGuard>;

// Saml assertion returned user attribute value
export const extendedSocialUserInfoGuard = socialUserInfoGuard.catchall(z.unknown());
export type ExtendedSocialUserInfo = z.infer<typeof extendedSocialUserInfoGuard>;
